@@ -1,6 +1,7 @@
 from __future__ import annotations
 
-from typing import Any, Callable, List
+from collections.abc import Callable
+from typing import Any
 
 from .handler import CallbackType, HandlerObject
 
@@ -25,7 +26,7 @@ class EventObserver:
     """
 
     def __init__(self) -> None:
-        self.handlers: List[HandlerObject] = []
+        self.handlers: list[HandlerObject] = []
 
     def register(self, callback: CallbackType) -> None:
         """
