@@ -1,10 +1,10 @@
 import asyncio
-import contextvars
 import inspect
 import warnings
+from collections.abc import Callable
 from dataclasses import dataclass, field
 from functools import partial
-from typing import Any, Callable, Dict, List, Optional, Set, Tuple
+from typing import Any
 
 from magic_filter.magic import MagicFilter as OriginalMagicFilter
 
@@ -21,7 +21,7 @@ CallbackType = Callable[..., Any]
 class CallableObject:
     callback: CallbackType
     awaitable: bool = field(init=False)
-    params: Set[str] = field(init=False)
+    params: set[str] = field(init=False)
     varkw: bool = field(init=False)
 
     def __post_init__(self) -> None:
@@ -31,7 +31,7 @@ class CallableObject:
         self.params = {*spec.args, *spec.kwonlyargs}
         self.varkw = spec.varkw is not None
 
-    def _prepare_kwargs(self, kwargs: Dict[str, Any]) -> Dict[str, Any]:
+    def _prepare_kwargs(self, kwargs: dict[str, Any]) -> dict[str, Any]:
         if self.varkw:
             return kwargs
 
@@ -46,7 +46,7 @@ class CallableObject:
 
 @dataclass
 class FilterObject(CallableObject):
-    magic: Optional[MagicFilter] = None
+    magic: MagicFilter | None = None
 
     def __post_init__(self) -> None:
         if isinstance(self.callback, OriginalMagicFilter):
@@ -65,7 +65,7 @@ class FilterObject(CallableObject):
                     stacklevel=6,
                 )
 
-        super(FilterObject, self).__post_init__()
+        super().__post_init__()
 
         if isinstance(self.callback, Filter):
             self.awaitable = True
@@ -73,17 +73,17 @@ class FilterObject(CallableObject):
 
 @dataclass
 class HandlerObject(CallableObject):
-    filters: Optional[List[FilterObject]] = None
-    flags: Dict[str, Any] = field(default_factory=dict)
+    filters: list[FilterObject] | None = None
+    flags: dict[str, Any] = field(default_factory=dict)
 
     def __post_init__(self) -> None:
-        super(HandlerObject, self).__post_init__()
+        super().__post_init__()
         callback = inspect.unwrap(self.callback)
         if inspect.isclass(callback) and issubclass(callback, BaseHandler):
             self.awaitable = True
         self.flags.update(extract_flags_from_object(callback))
 
-    async def check(self, *args: Any, **kwargs: Any) -> Tuple[bool, Dict[str, Any]]:
+    async def check(self, *args: Any, **kwargs: Any) -> tuple[bool, dict[str, Any]]:
         if not self.filters:
             return True, kwargs
         for event_filter in self.filters:
