@@ -14,6 +14,7 @@ from ..types import (
     MessageEntity,
     ReplyMarkupUnion,
     ReplyParameters,
+    SuggestedPostParameters,
 )
 from .base import TelegramMethod
 
@@ -36,6 +37,8 @@ class SendVideo(TelegramMethod[Message]):
     """Unique identifier of the business connection on behalf of which the message will be sent"""
     message_thread_id: Optional[int] = None
     """Unique identifier for the target message thread (topic) of the forum; for forum supergroups only"""
+    direct_messages_topic_id: Optional[int] = None
+    """Identifier of the direct messages topic to which the message will be sent; required if the message is sent to a direct messages chat"""
     duration: Optional[int] = None
     """Duration of sent video in seconds"""
     width: Optional[int] = None
@@ -68,6 +71,8 @@ class SendVideo(TelegramMethod[Message]):
     """Pass :code:`True` to allow up to 1000 messages per second, ignoring `broadcasting limits <https://core.telegram.org/bots/faq#how-can-i-message-all-of-my-bot-39s-subscribers-at-once>`_ for a fee of 0.1 Telegram Stars per message. The relevant Stars will be withdrawn from the bot's balance"""
     message_effect_id: Optional[str] = None
     """Unique identifier of the message effect to be added to the message; for private chats only"""
+    suggested_post_parameters: Optional[SuggestedPostParameters] = None
+    """A JSON-serialized object containing the parameters of the suggested post to send; for direct messages chats only. If the message is sent as a reply to another suggested post, then that suggested post is automatically declined."""
     reply_parameters: Optional[ReplyParameters] = None
     """Description of the message to reply to"""
     reply_markup: Optional[ReplyMarkupUnion] = None
@@ -96,6 +101,7 @@ class SendVideo(TelegramMethod[Message]):
             video: InputFileUnion,
             business_connection_id: Optional[str] = None,
             message_thread_id: Optional[int] = None,
+            direct_messages_topic_id: Optional[int] = None,
             duration: Optional[int] = None,
             width: Optional[int] = None,
             height: Optional[int] = None,
@@ -114,6 +120,7 @@ class SendVideo(TelegramMethod[Message]):
             protect_content: Optional[Union[bool, Default]] = Default("protect_content"),
             allow_paid_broadcast: Optional[bool] = None,
             message_effect_id: Optional[str] = None,
+            suggested_post_parameters: Optional[SuggestedPostParameters] = None,
             reply_parameters: Optional[ReplyParameters] = None,
             reply_markup: Optional[ReplyMarkupUnion] = None,
             allow_sending_without_reply: Optional[bool] = None,
@@ -129,6 +136,7 @@ class SendVideo(TelegramMethod[Message]):
                 video=video,
                 business_connection_id=business_connection_id,
                 message_thread_id=message_thread_id,
+                direct_messages_topic_id=direct_messages_topic_id,
                 duration=duration,
                 width=width,
                 height=height,
@@ -145,6 +153,7 @@ class SendVideo(TelegramMethod[Message]):
                 protect_content=protect_content,
                 allow_paid_broadcast=allow_paid_broadcast,
                 message_effect_id=message_effect_id,
+                suggested_post_parameters=suggested_post_parameters,
                 reply_parameters=reply_parameters,
                 reply_markup=reply_markup,
                 allow_sending_without_reply=allow_sending_without_reply,
