@@ -6,8 +6,9 @@ except ImportError:  # pragma: no cover
 
     class LazyProxy:  # type: ignore
         def __init__(self, func: Any, *args: Any, **kwargs: Any) -> None:
-            raise RuntimeError(
+            msg = (
                 "LazyProxy can be used only when Babel installed\n"
                 "Just install Babel (`pip install Babel`) "
                 "or aiogram with i18n support (`pip install aiogram[i18n]`)"
             )
+            raise RuntimeError(msg)
